using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;

namespace InsertGridSample
{
	public class DummyData :NSObject
	{
		[Export("index")]
		public int Index{get;set;}

		[Export("firstName")]
		public string FirstName{get;set;}

		[Export("lastName")]
		public string LastName{get;set;}

	}
	

	public class CustomDataSourceHelper :IGGridViewDataSourceHelper
	{
		public override NSObject[] GetStretchRows (IGGridView gridView)
		{
			// Mark the Add New Row as a stretch row (this means it will only be one column)
			return new NSObject[] { new IGRowPath(0,0) };
		}

		public override int NumberOfRowsInSection (IGGridView gridView, int section)
		{
			int count = 0;

			if(this.Data != null)
			{
				if(this.Sections.Length == 0)
					count = this.DisplayData.Length;
				else
				{
					NSArray grouping = (NSArray)this.SectionData.ValueForKey ((NSString)this.Sections.GetValue(section));
					count = (int)grouping.Count;
				}
			}

			count++; // Add One more Row for the "Add New" row

			return count;
		}

		public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path)
		{
			IGCellPath normPath = this.NormalizePath (path);

			if (normPath.RowIndex == 0) {

				// Create the add New Row, as the first row.
				IGGridViewCell cell = (IGGridViewCell)gridView.DequeueReusableCell ("ADDNewCell");
				if (cell == null) {
					cell = new IGGridViewCell ("ADDNewCell");
					UIButton b = new UIButton (UIButtonType.RoundedRect);
					b.SetTitle (@"Add", UIControlState.Normal);
					b.Frame = new RectangleF (0, 0, cell.Frame.Size.Width, cell.Frame.Size.Height);
					b.AutoresizingMask = UIViewAutoresizing.FlexibleHeight | UIViewAutoresizing.FlexibleWidth;
					cell.AddSubview (b);

				}

				return cell;

			} else {
				normPath = new IGCellPath (path.RowIndex - 1, path.SectionIndex, path.ColumnIndex);
				path = this.DenormalizePath (normPath);
				IGGridViewColumnDefinition colDef = (IGGridViewColumnDefinition)this.Columns.GetValue (normPath.ColumnIndex);
				if (colDef != null) {
					IGGridViewCell cell = colDef.CreateCell (gridView, path, this);
					return cell;
				}
			}

			return null;

		}

	}

	public partial class InsertGridSampleViewController : UIViewController
	{
		IGGridView _gridView;
		IGGridViewDataSourceHelper _dsh;
		List<NSObject> _data = new List<NSObject>();

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			this.View.BackgroundColor = UIColor.White;

			// Create a new gridview
			_gridView = new IGGridView( new RectangleF(0,0,(this.View.Bounds.Width),this.View.Bounds.Height),IGGridViewStyle.IGGridViewStyleDefault);

			// Enable flexible width so that the grid feels its parents view
			_gridView.AutoresizingMask = UIViewAutoresizing.FlexibleDimensions;


			this.View.Add(_gridView);


			_dsh = new CustomDataSourceHelper ();

			this.GenerateData ();
			// Add data to the grid
			_dsh.Data = _data.ToArray ();
			_gridView.DataSource = _dsh;
		}

		public void GenerateData()
		{
			for (int i = 1; i < 26; i++)
			{
				DummyData obj = new DummyData ();
				obj.FirstName = i.ToString ();
				obj.LastName = "Last Name: " + i.ToString ();
				obj.Index = i;
				_data.Add(obj);
			}
		}
	}
}

